==> org.eclipse.mylyn.tasks.ui.source_3.26.1.v20230604-1755.jar: org/eclipse/mylyn/internal/tasks/ui/editors/TaskHyperlinkTextPresentationManager.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2008 David Green and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     David Green - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.ui.editors;

import org.eclipse.jface.text.hyperlink.IHyperlink;
import org.eclipse.mylyn.internal.tasks.core.TaskList;
import org.eclipse.mylyn.internal.tasks.ui.TasksUiPlugin;
import org.eclipse.mylyn.tasks.core.ITask;
import org.eclipse.mylyn.tasks.ui.TaskHyperlink;
import org.eclipse.swt.custom.StyleRange;

/**
 * A manager that decorates task hyperlinks with strike-through when the task is completed.
 * 
 * @author David Green
 */
public class TaskHyperlinkTextPresentationManager extends AbstractHyperlinkTextPresentationManager {

	private final TaskList taskList = TasksUiPlugin.getTaskList();

	@Override
	public boolean select(IHyperlink hyperlink) {
		if (hyperlink instanceof TaskHyperlink) {
			TaskHyperlink taskHyperlink = (TaskHyperlink) hyperlink;
			String taskId = taskHyperlink.getTaskId();
			String repositoryUrl = taskHyperlink.getRepository().getRepositoryUrl();

			ITask task = taskList.getTask(repositoryUrl, taskId);
			if (task == null) {
				task = taskList.getTaskByKey(repositoryUrl, taskId);
			}
			return task != null && task.isCompleted();
		}
		return false;
	}

	@Override
	protected void decorate(StyleRange styleRange) {
		// currently only strike-through is used to indicate completed tasks
		styleRange.strikeout = true;
	}

}

==> org.eclipse.mylyn.tasks.ui.source_4.2.0.v20240207-0505.jar: org/eclipse/mylyn/internal/tasks/ui/editors/TaskHyperlinkTextPresentationManager.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2008 David Green and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0
 * 
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     David Green - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.ui.editors;

import org.eclipse.jface.text.hyperlink.IHyperlink;
import org.eclipse.mylyn.internal.tasks.core.TaskList;
import org.eclipse.mylyn.internal.tasks.ui.TasksUiPlugin;
import org.eclipse.mylyn.tasks.core.ITask;
import org.eclipse.mylyn.tasks.ui.TaskHyperlink;
import org.eclipse.swt.custom.StyleRange;

/**
 * A manager that decorates task hyperlinks with strike-through when the task is completed.
 * 
 * @author David Green
 */
public class TaskHyperlinkTextPresentationManager extends AbstractHyperlinkTextPresentationManager {

	private final TaskList taskList = TasksUiPlugin.getTaskList();

	@Override
	public boolean select(IHyperlink hyperlink) {
		if (hyperlink instanceof TaskHyperlink taskHyperlink) {
			String taskId = taskHyperlink.getTaskId();
			String repositoryUrl = taskHyperlink.getRepository().getRepositoryUrl();

			ITask task = taskList.getTask(repositoryUrl, taskId);
			if (task == null) {
				task = taskList.getTaskByKey(repositoryUrl, taskId);
			}
			return task != null && task.isCompleted();
		}
		return false;
	}

	@Override
	protected void decorate(StyleRange styleRange) {
		// currently only strike-through is used to indicate completed tasks
		styleRange.strikeout = true;
	}

}
